<?php

namespace Drupal\solr_health_check\Form;

use Drupal\Core\Form\ConfigFormBase;
use Drupal\Core\Form\FormStateInterface;

/**
 * Class for managing Solr Health Check settings form.
 */
class SolrHealthCheckSettingsForm extends ConfigFormBase {

  /**
   * {@inheritdoc}
   */
  protected function getEditableConfigNames() {
    return ['solr_health_check.settings'];
  }

  /**
   * {@inheritdoc}
   */
  public function getFormId() {
    return 'solr_health_check_settings_form';
  }

  /**
   * {@inheritdoc}
   */
  public function buildForm(array $form, FormStateInterface $form_state) {
    $config = $this->config('solr_health_check.settings');

    $form['endpoint_path'] = [
      '#type' => 'textfield',
      '#title' => $this->t('Endpoint URL'),
      '#default_value' => $config->get('endpoint_path'),
      '#description' => $this->t('Specify the custom endpoint URL for the Solr health check.'),
      '#required' => TRUE,
    ];

    $form['return_500_on_error'] = [
      '#type' => 'checkbox',
      '#title' => $this->t('Return 500 if any core is down'),
      '#default_value' => $config->get('return_500_on_error'),
      '#description' => $this->t('Check this box to return a 500 status code if any of the Solr cores are down.'),
    ];

    return parent::buildForm($form, $form_state);
  }

  /**
   * {@inheritdoc}
   */
  public function submitForm(array &$form, FormStateInterface $form_state) {
    $this->config('solr_health_check.settings')
      ->set('endpoint_path', $form_state->getValue('endpoint_path'))
      ->set('return_500_on_error', $form_state->getValue('return_500_on_error'))
      ->save();

    parent::submitForm($form, $form_state);
  }

}
